@@ -1,28 +1,33 @@
 
-from .dates import is_date
+from .text import print_runtime
+from .text import print_performance
+from .text import styled
+
 from .dates import to_datetime
+from .dates import attempt_to_datetime
 from .dates import parse_timedelta
 from .dates import parse_seconds
 
 from .filesystem import read_file
 from .filesystem import write_file
 from .filesystem import parse_path
+from .filesystem import traverse_dir
 
 from .iter import transpose
 
-from .text import print_runtime
-from .text import print_performance
-from .text import styled
-
 
 __all__ = ['print_runtime',
            'print_performance',
            'styled',
+
            'to_datetime',
-           'is_date',
+           'attempt_to_datetime',
            'parse_timedelta',
            'parse_seconds',
+
            'read_file',
            'write_file',
            'parse_path',
+           'traverse_dir',
+
            'transpose']
